[![pypi version](https://img.shields.io/pypi/v/hawkei?style=flat-square)](https://www.npmjs.com/org/hawkei)
[![build status](https://img.shields.io/travis/hawkei-io/hawkei-python.svg?style=flat-square)](https://travis-ci.org/hawkei-io/hawkei-python)

# Hawkei

[Hawkei](https://hawkei.io) Python library

Interact easily with our API using our Python library.

## Setup

- [Start by creating an account](https://app.hawkei.io/registration)
- Follow the [Quick Start Guide](https://hawkei.atlassian.net/wiki/spaces/HAW/pages/4915206/Getting+started+in+4+steps) to get set up
- Use our [Javascript Library](https://hawkei.atlassian.net/wiki/spaces/HAW/pages/5570561/Python) to install and configure Hawkei for your platform.

## Documentation & Usage

Documentation is available at [hawkei.atlassian.net/wiki/spaces/HAW/pages/5570561/Python](https://hawkei.atlassian.net/wiki/spaces/HAW/pages/5570561/Python)
